CoverageService class

Constructors

CoverageService({Directory? currentDirectory})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkCoverage({required String filePath, required double minCoverage, List<String> excludePaths = const [], bool excludeGenerated = false, String? baselinePath}) Future<CoverageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited